<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * @package galo
 * @since galo 1.0
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @param array $args Configuration arguments.
 * @return array
 */
function galo_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'galo_page_menu_args' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function galo_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	return $classes;
}
add_filter( 'body_class', 'galo_body_classes' );

/**
 * Filters wp_title to print a neat <title> tag based on what is being viewed.
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 */
function galo_wp_title( $title, $sep ) {
	if ( is_feed() ) {
		return $title;
	}
	
	global $page, $paged;

	// Add the blog name
	$title .= get_bloginfo( 'name', 'display' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title .= " $sep $site_description";
	}

	// Add a page number if necessary:
	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
		$title .= " $sep " . sprintf( __( 'Page %s', 'galo' ), max( $paged, $page ) );
	}

	return $title;
}
add_filter( 'wp_title', 'galo_wp_title', 10, 2 );

/**
 * Sets the authordata global when viewing an author archive.
 *
 * This provides backwards compatibility with
 * http://core.trac.wordpress.org/changeset/25574
 *
 * It removes the need to call the_post() and rewind_posts() in an author
 * template to print information about the author.
 *
 * @global WP_Query $wp_query WordPress Query object.
 * @return void
 */
function galo_setup_author() {
	global $wp_query;

	if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
		$GLOBALS['authordata'] = get_userdata( $wp_query->post->post_author );
	}
}
add_action( 'wp', 'galo_setup_author' );

/**
 * Portfolio Post Type
 *
 * @since galo 1.0
 */
if ( ! function_exists( 'galo_portfolio_post_type' ) ) {
	function galo_portfolio_post_type() {

		$labels = array(
			'name' => __( 'Portfolio', 'galo' ),
			'singular_name' => __( 'Portfolio Item', 'galo' ),
			'add_new' => __( 'Add New Item', 'galo' ),
			'add_new_item' => __( 'Add New Portfolio Item', 'galo' ),
			'edit_item' => __( 'Edit Portfolio Item', 'galo' ),
			'new_item' => __( 'Add New Portfolio Item', 'galo' ),
			'view_item' => __( 'View Item', 'galo' ),
			'search_items' => __( 'Search Portfolio', 'galo' ),
			'not_found' => __( 'No portfolio items found', 'galo' ),
			'not_found_in_trash' => __( 'No portfolio items found in trash', 'galo' )
		);
		$args = array(
			'labels' => $labels,
			'public' => true,
			'supports' => array( 'title', 'editor', 'thumbnail', 'comments', 'post-formats' ),
			'capability_type' => 'post',
			'rewrite' => array("slug" => "portfolio"), // Permalinks format
			'menu_position' => 5,
			'has_archive' => true
		);
		register_post_type( 'portfolio', $args );
	}
	add_action( 'init', 'galo_portfolio_post_type' );
}

/* Portfolio Categories */
if ( ! function_exists( 'galo_portfolio_taxonomy' ) ) {
	function galo_portfolio_taxonomy() {
		// Add new taxonomy, make it hierarchical (like categories)
		$labels = array(
			'name'              => _x( 'Portfolio Categories', 'taxonomy general name', 'galo' ),
			'singular_name'     => _x( 'Portfolio Category', 'taxonomy singular name', 'galo' ),
			'search_items'      => __( 'Search Portfolio Categories', 'galo' ),
			'all_items'         => __( 'All Portfolio Categories', 'galo' ),
			'parent_item'       => __( 'Parent Portfolio Category', 'galo' ),
			'parent_item_colon' => __( 'Parent Portfolio Category:', 'galo' ),
			'edit_item'         => __( 'Edit Portfolio Category', 'galo' ),
			'update_item'       => __( 'Update Portfolio Category', 'galo' ),
			'add_new_item'      => __( 'Add New Portfolio Category', 'galo' ),
			'new_item_name'     => __( 'New Portfolio Category Name', 'galo' ),
			'menu_name'         => __( 'Portfolio Category', 'galo' ),
		);

		$args = array(
			'hierarchical'      => true,
			'labels'            => $labels,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'portfolio_category' ),
		);

		register_taxonomy( 'portfolio_category', array( 'portfolio' ), $args );
	}
	add_action( 'init', 'galo_portfolio_taxonomy', 0 );
}

/**
 * Facebook Open Graph
 *
 * @since galo 1.0
 */
function galo_fb_open_graph_tags() {
	if (is_single()) {
		global $post;
		if(get_the_post_thumbnail($post->ID, 'thumbnail')) {
			$thumbnail_id = get_post_thumbnail_id($post->ID);
			$thumbnail_object = get_post($thumbnail_id);
			$image = $thumbnail_object->guid;
		} else {	
			$image = ''; // Change this to the URL of the logo you want beside your links shown on Facebook
		}
		//$description = get_bloginfo('description');
		$description = my_excerpt( $post->post_content, $post->post_excerpt );
		$description = strip_tags($description);
		$description = str_replace("\"", "'", $description);
?>
<meta property="og:title" content="<?php the_title(); ?>" />
<meta property="og:type" content="article" />
<meta property="og:image" content="<?php echo $image; ?>" />
<meta property="og:url" content="<?php the_permalink(); ?>" />
<meta property="og:description" content="<?php echo $description ?>" />
<meta property="og:site_name" content="<?php echo get_bloginfo('name'); ?>" />

<?php 	}
}

function my_excerpt($text, $excerpt){
	
    if ($excerpt) return $excerpt;

    $text = strip_shortcodes( $text );

    $text = apply_filters('the_content', $text);
    $text = str_replace(']]>', ']]&gt;', $text);
    $text = strip_tags($text);
    $excerpt_length = apply_filters('excerpt_length', 55);
    $excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
    $words = preg_split("/[\n
	 ]+/", $text, $excerpt_length + 1, PREG_SPLIT_NO_EMPTY);
    if ( count($words) > $excerpt_length ) {
            array_pop($words);
            $text = implode(' ', $words);
            $text = $text . $excerpt_more;
    } else {
            $text = implode(' ', $words);
    }

    return apply_filters('wp_trim_excerpt', $text, $excerpt);
}
add_action('wp_head', 'galo_fb_open_graph_tags');